@@ -1,7 +1,5 @@
-
 from syned.beamline.optical_element import OpticalElement
-from syned.beamline.shape import BoundaryShape
 
 class IdealElement(OpticalElement):
-    def __init__(self, name="Undefined", boundary_shape=BoundaryShape()):
+    def __init__(self, name="Undefined", boundary_shape=None):
         OpticalElement.__init__(self, name=name, boundary_shape=boundary_shape)
\ No newline at end of file
